# Static file handling

## Individual file

It is possible to serve static files with tail path pattern and `NamedFile`.

```rust
extern crate actix_web;
use actix_web::*;
use std::path::PathBuf;

fn index(req: HttpRequest) -> Result<fs::NamedFile> {
    let path: PathBuf = req.match_info().query("tail")?;
    Ok(fs::NamedFile::open(path)?)
}

fn main() {
    Application::default("/")
        .resource(r"/a/{tail:*}", |r| r.method(Method::GET).handler(index))
        .finish();
}
```

## Directory

To serve files from specific directory and sub-directories `StaticFiles` type could be used. 
`StaticFiles` could be registered with `Application::route` method.

```rust
extern crate actix_web;

fn main() {
    actix_web::Application::default("/")
        .route("/static", actix_web::fs::StaticFiles::new(".", true))
        .finish();
}
```

First parameter is a base directory. Second parameter is *show_index*, if it is set to *true*
directory listing would be returned for directories, if it is set to *false*
then *404 Not Found* would be returned instead of directory listing.
